#
# spec file for package Herwig
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_name Herwig-libs
Name:           Herwig
Version:        7.3.0
Release:        1.4
Summary:        Multi-purpose event generator for high-energy physics
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            http://herwig.hepforge.org/
Source0:        http://www.hepforge.org/archive/herwig/%{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE Herwig-disable-repo-install.patch badshah400@gmail.com -- Disable post-install hooks intended to set up the Herwig repo, this doesn't work inside the build script because of missing LHAPDF data that needs to be installed by the user; the install-hook doesn't serve any purpose while building the rpm and users can easily set this up on their own
Patch0:         Herwig-disable-repo-install.patch
# PATCH-FIX-UPSTREAM Herwig-type-mismatch-fix.patch badshah400@gmail.com -- Fix a type mismatch error in fortran flagged by GCC 10
Patch1:         Herwig-type-mismatch-fix.patch
BuildRequires:  HepMC-devel
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
BuildRequires:  ThePEG-devel >= 2.3.0
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(gsl)
ExcludeArch:    %{ix86} %{arm}

%description
Herwig is a multi-purpose particle physics event generator.
Herwig 7.0 (Herwig++ 3.0) replaces any prior HERWIG or Herwig++ versions.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

%package -n %{so_name}
Summary:        Multi purpose event generator for high energy physics
Group:          System/Libraries
Obsoletes:      libHerWig1 < %{version}-%{release}

%description -n %{so_name}
Herwig is a multi-purpose particle physics event generator.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

This package provides the shared libraries for %{name}.

%package devel
Summary:        Multi purpose event generator for high energy physics
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}
Requires:       ThePEG-devel
Provides:       Herwig++-devel = %{version}
Obsoletes:      Herwig++-devel < %{version}

%description devel
Herwig is a multi-purpose particle physics event generator.
Herwig 7.0 (Herwig++ 3.0) replaces any prior HERWIG or Herwig++ versions.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

This package provides the header and source libraries for development
with %{name}.

%prep
%autosetup -p1
# autoconf macros assume x86_64 is the only 64 bit arch
sed -i -e 's/"${host_cpu}" == "x86_64"/%{__isa_bits} == 64/' m4/{fastjet,herwig}.m4

# FIX ENV BASED HASHBANG
sed -i "1{s|/usr/bin/env bash|/bin/bash|}" src/herwig-config.in

%build
# default-integer-8 only set for x86_64 by upstream
export FCFLAGS="%{?build_fflags} -fdefault-integer-8"
autoreconf -fvi
%configure --disable-static
%make_build

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

find %{buildroot} -type f -name "*.la" -delete -print

# Remove unnecessary hashbangs
sed -i "1{/\/usr\/bin\/env/d;}" %{buildroot}%{_libdir}/%{name}/python/slha2herwig
sed -i "1{/\/usr\/bin\/env/d;}" %{buildroot}%{_libdir}/%{name}/python/ufo2herwig

# Fix hashbangs to directly point to python
for exe in gosam2herwig herwig-mergegrids mg2herwig slha2herwig ufo2herwig
do
 sed -i "1{s/\/usr\/bin\/env python/\/usr\/bin\/python3/;}" %{buildroot}%{_bindir}/${exe}
done

%fdupes -s %{buildroot}%{_libdir}/%{name}/
%fdupes -s %{buildroot}%{_datadir}/%{name}/

%post -n %{so_name} -p /sbin/ldconfig
%postun -n %{so_name} -p /sbin/ldconfig

%files -n %{so_name}
%doc AUTHORS GUIDELINES ChangeLog README
%license COPYING
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so.*

%files devel
%{_bindir}/Herwig
%{_bindir}/herwig-combinedistributions
%{_bindir}/herwig-combineruns
%{_bindir}/herwig-makedistributions
%{_bindir}/herwig-mergegrids
%{_bindir}/herwig-config
%{_bindir}/ufo2herwig
%{_bindir}/slha2herwig
%{_bindir}/gosam2herwig
%{_bindir}/mg2herwig
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/python/
%{_includedir}/%{name}/
%{_datadir}/%{name}/

%changelog
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 7.3.0:
  * electroweak radiations added to the default parton shower
  * HQET spin hadronization and decay have been implemented to
    improve the predictions of excited heavy mesons and heavy
    baryons
  * dot-preserving treatment of the default parton shower
    evolution scale has been implemented
  * infrastructure for dynamic hadronization model and dark
    hadronization added
  * kinematic treatment of cluster splitting in cluster
    fissioner improved
  * new global tune implemented
  * several bugs fixed
- Update to version 7.2.3:
  * improved ufo2herwig tool
  * improved remnant handling for photon collisions
  * improved high-energy behaviour of default parton shower
* Fri Mar 19 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.2.2:
  * support for python 3 and gcc 10.
  * ufo2herwig script is updated to be compatible with python 2
    and 3, using --convert option.
- Rebase Herwig-disable-repo-install.patch for update.
* Mon Jun  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.2.1:
  * Vertex position fix for taus in dipole shower events.
- Add Herwig-type-mismatch-fix.patch to fix data of incorrect type
  sent to functions, flagged by GCC 10.
- Use autosetup instead of individual patch commands.
- Use %%make_build which automatically uses parallel threads and
  makes the compilation more verbose.
- Remove a spurious .orig file.
* Fri Jan 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Switch to python3.
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to vesion 7.2.0:
  * Improvements to the simulation of multiple-parton
    interactions, including diffractive processes.
  * A new model for baryonic colour reconnection.
  * Spin correlations in both the dipole and angular-ordered
    parton showers.
  * Improvements to strangeness production.
  * An improved choice of evolution variable in the
    angular-ordered parton shower.
  * Support for generic Lorentz structures in BSM models.
- Changes from Herwig 7.1.6 release:
  * Fix if no W in top in external events.
  * Vertex position fix for dip[ole shower events.
  * Update boost m4.
  * Add max,min, re, im to functions for ufo conversion.
  * Comparision operators should be const, issues with C++17.
- Update required verion of ThePEG-devel: version 2.2.0 now
  required.
- Fix an env-based hashbang.
- Use fdupes also on %%{_datadir} to link a pair of duplicated
  files.
- Remove a spurious backup file that gets installed otherwise.
* Wed Jul 17 2019 Atri Bhattacharya <badshah400@gmail.com>
- Disable LTO to prevent resulting build failure.
* Thu May  2 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.1.5:
  * Add option of producing partons on physically mass shell after
    the parton shower to allow the string model to be used to
    hadronize events
  * Fixes for template issues and compiler warnings for gcc8,9,
    icc and clang
  * Fixes to the calculation of W, Z and h widths if decay modes
    removed
  * Fix typo in FI g to gg dipole.
  * Fix to allow 1 parameter to specify the mass of more than one
    particle in the UFO converter
  * Fix to partial width calculation of VSS decays
  * Fix the PDF assignment for DIS processes with Matchbox
  * Fix for undecayed W bosons in internal POWHEG gauge boson pair
    code
  * Update boost detection in configure script
- Changes from version 7.1.4:
  * More matrix elements and better handling of BSM physics
  * Fix for spin correlations in angular-ordered shower, effects
    top decays
  * Allow fixed target collisions
  * various minor fixes
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 7.1.3:
  * Dipole Shower
  - Changed default phase space limits
  - g -> gg splitting function asymmetrized
  - Initial retune supplied, given the visible changes
    to LEP observables
  * Added new Baryonic colour reconnection model (arXiv
    1710:10906)
  * Added Schuler-Sjostrand Photon PDFs
  * Handling of massless taus from external sources
  * various minor fixes
  * use std::array<> where possible
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Build Herwig only on x86_64 since other archs are not supported
* Sun Nov  5 2017 badshah400@gmail.com
- Update to version 7.1.2:
  * Reduction of the default pt cut for QED radiation off leptons.
  * Inputfile changes due to new read mode in ThePEG.  ThePEG
    remains in current repo dir when reading input-file/snippet.
  * Fix for shower scale variations in qtilde shower.
  * All standard input files now use the tuned intrinsic pt.
  * Remove obsolete input files for various tunes.
  * Fix for Madgraph interface for NLO corrections with recent
    version.
  * Run file size reduction for processes using madgraph/openloops.
  * Fix in jacobian for massive dipole kinematics.
  * General improvements for UFO model handling.
- Fix env based hashbangs (/usr/bin/env python -> /usr/bin/python,
  etc.).
* Wed Oct 11 2017 badshah400@gmail.com
- Use more fine-grained BuildRequires on boost* libraries for
  openSUSE > 1320.
* Sat Sep  2 2017 badshah400@gmail.com
- Build with HepMC2-devel, since Rivet does not compile with
  HepMC-devel >= 3 yet.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 7.1.1:
  * Snippets are now all installed
  * Fixed broken ufo2herwig output and LHC-MB.in
  * UFO improvements
  - More robust SLHA file handling
  - option of creating diagonal mixing matrices, needed for
    ATLAS simplfied models
  - Improved warnings about resetting standard model particles
  - Fixed certain cases where the wrong lorentz structure was
    picked in VVS vertices
  * Improved error message for unhandled beam particles
  * Fix for Dipole Shower chain selection
  * Fixed crash in double diffractive delta resonances
- Changes from version 7.1.0:
  * For a more detailed overview and further references please see
    the release note arXiv:1705.06919
  * NLO multijet merging with the dipole shower
  * A new soft model
  * An interface to EvtGen
  * Improved calculation of mass effects in the dipole shower
  * Top decays in the dipole shower, and NLO corrections to the
    decay
  * An implementation of the KrkNLO method for simple processes
  * Major restructuring and cleanup of default input files
  * C++11 is now mandatory and heavily used in the code
  * Many smaller bugfixes and improvements
- Update filelist for new and dropped binaries.
- Disable for %%{ix86}: no longer supported.
- Rebase Herwig-disable-repo-install.patch for update.
* Mon Feb 13 2017 jengelh@inai.de
- Rename from libHerWig1 to Herwig-libs as the package does not
  satisfy the SLPP guideline: there are a number of non-.so.1
  files.
* Wed Nov 16 2016 jengelh@inai.de
- Trim history lesson from description
* Tue Nov 15 2016 badshah400@gmail.com
- Rename shared library, adding the so number from
  libHerwigAPI.so; the so numbers of the other shared libraries
  are expected to be incremented by upstream in step with this.
- Move config file to -devel pkg in keeping with shlib packaging
  policy.
- Added obsoletes/provides for Herwig++ which will now be dropped
  from Factory.
* Fri Nov 11 2016 badshah400@gmail.com
- Initial package.
- Add Herwig-disable-repo-install.patch: Disable post-install
  hooks intended to set up the Herwig repo, this doesn't work
  inside the build script because of missing LHAPDF data that
  needs to be installed by the user; the install-hook doesn't
  serve any purpose while building the rpm and users can easily
  set this up on their own.
